@@ -1,5 +1,5 @@
 package Bot::BasicBot::Pluggable;
-$Bot::BasicBot::Pluggable::VERSION = '1.11';
+$Bot::BasicBot::Pluggable::VERSION = '1.20';
 use warnings;
 use strict;
 
@@ -348,7 +348,7 @@ BEGIN {
     my @dispatchable_events = (
         qw/
           connected chanjoin chanpart userquit nick_change
-          topic kicked
+          topic kicked raw_in raw_out
           /
     );
     my @priority_events = (qw/ said emoted /);
@@ -378,7 +378,7 @@ Bot::BasicBot::Pluggable - extended simple IRC bot for pluggable modules
 
 =head1 VERSION
 
-version 1.11
+version 1.20
 
 =head1 SYNOPSIS
 
